about summary refs log tree commit diff stats
path: root/gomponents_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'gomponents_test.go')
-rw-r--r--gomponents_test.go6
1 files changed, 4 insertions, 2 deletions
diff --git a/gomponents_test.go b/gomponents_test.go
index 3064c0f..db2dfee 100644
--- a/gomponents_test.go
+++ b/gomponents_test.go
@@ -205,9 +205,11 @@ func TestRaw(t *testing.T) {
 }
 
 func ExampleRaw() {
-	e := g.El("span", g.Raw("<strong>Party</strong> hats &gt; normal hats."))
+	e := g.El("span",
+		g.Raw(`<button onclick="javascript:alert('Party time!')">Party hats</button> &gt; normal hats.`),
+	)
 	_ = e.Render(os.Stdout)
 	// Output: <span><strong>Party</strong> hats &gt; normal hats.</span>
 }
 
 func TestGroup(t *testing.T) {
@@ -205,9 +205,11 @@ func TestRaw(t *testing.T) {
 	_ = e.Render(os.Stdout)
-	// Output: <span><strong>Party</strong> hats &gt; normal hats.</span>
+	// Output: <span><button onclick="javascript:alert('Party time!')">Party hats</button> &gt; normal hats.</span>
 }
 